use Config;
use ExtUtils::Embed;

my $glib_cflags = qx<glib-config --cflags>;
my $glib_libs   = qx<glib-config --libs>;

s/[\r\n]//g for ($glib_cflags, $glib_libs);
  
%mime = (
      "application/x-mperl:mperl:Embedded Perl"                => "Browser::Plugin::Plain",
      "application/x-mperl-gtk:gmperl:Embedded Perl (gtk+)"    => "Browser::Plugin::Gtk",
      "application/x-mperl-tk:tmperl:Embedded Perl (Tk)"       => "Browser::Plugin::Tk",
      "application/x-mperl-event:emperl:Embedded Perl (Event)" => "Browser::Plugin::Event",
);

my $ldopts = ldopts (0);
my $ccopts = ccopts;

$cc  = $Config{cc};
$ld  = $Config{ld};
$inc = "-I. -ISDK/Include -ISDK/Common";

sub str($) {
   local $_ = shift;
   s/\\/\\\\/g;
   s/"/\\"/g;
   s/\r?\n/\\n\" \\\n\"/g;
   "\"$_\"";
}

$name = "Embedded Mozilla Perl Interpreter";
$mime = join ";", keys %mime;
$desc = <<EOF;

<table bgcolor="white" border="0"><tr><td><font color="black"> <h3><a
href="http://mozperl.plan9.de/">Mozilla Perl Interface</a></h3><p>This
plug-in allows you to execute <a href="http://www.perl.org/">perl
programs</a> embedded in html pages and other nifty things. Perl is a
portable (even more so than java ;) programming language used since
many years on the internet. For more information on perl, visit the <a
href="http://www.perl.org/">www.perl.org</a> Website. For more information
on Mozilla-Perl, visit the <a href="http://mozperl.plan9.de/">Mozilla-Perl
homepage (<tt>mozperl.plan9.de</tt>)</a>.</p> </font></td></tr></table>

EOF

%def = (
   OSNAME      => str$Config{osname},
   OSVERS      => str$Config{osvers},
   PLUGIN_NAME => str$name,
   PLUGIN_DESC => str$desc,
   MIMETYPES   => str$mime,
   PERLPATH    => str$Config{perlpath},
   PATHSEP     => str"/",
);

$def{HAVE_GLIB}   = 1 if $glib_libs ne $glib_cflags;

if ($^O eq "Win32") {
   $def{IFACE} = '"npwin.cpp"';
   delete $def{HAVE_ATHENA};
   die;
} else {
   $def{IFACE} = str"npunix.c",

   $def{HAVE_ATHENA} = 1;
   $x_libs = "-L/usr/X11/lib -L/usr/X11R6/lib -lX11 -lXt";
   $inc .= " -I/usr/X11/include -I/usr/X11R6/include";

   if ($^O eq "aix") {
      die;
   } elsif ($^O eq "hpux") {
      die;
   } elsif ($^O eq "linux") {
      # ...
   } else {
      die "unsupported operating system $^O\n";
   }
}

print "Writing ns4/interp.h\n";

open INTERP, ">interp.h" or die "interp.h: $!";
print INTERP "static interp perl_interp[] = {\n";
while (my ($mime, $module) = each %mime) {
   my ($mime, $suffix, $desc) = split /:/, $mime;
   printf INTERP "   { %s, %s, %s, %s },\n", map str$_, $mime, $suffix, $desc, $module;

}
print INTERP "   { 0 }\n};\n";
close INTERP;

print "Writing ns4/config.h\n";

open CONFIG, ">config.h" or die "config.h: $!";
while (my ($k, $v) = each %def) {
   print CONFIG "#define $k $v\n";
}
close CONFIG;

print "Writing ns4/Makefile\n";

open MAKEFILE, ">Makefile" or die "Makefile: $!";
print MAKEFILE <<EOF;

OBJ   = $Config{obj_ext}
DLEXT = $Config{dlext}
CC    = $cc $ccopts $glib_cflags $inc $def $Config{optimize}
LD    = $ld
LIBS  = $ldopts $glib_libs $x_libs
PERL  = $Config{perlpath}

OBJ_LIB = np_perl\$(OBJ)

all :: np_perl.\$(DLEXT)

np_perl\$(OBJ): np_perl.c config.h
	\$(CC) $Config{cccdlflags} -c \$<

np_perl.\$(DLEXT) : \$(OBJ_LIB)
	\$(LD) $Config{lddlflags} -o \$@ \$(OBJ_LIB) \$(LIBS)

genconst: genconst.c.PL
	\$(PERL) genconst.c.PL	
	\$(CC) -o genconst genconst.c
   
apiconst.pl: genconst
	./genconst >apiconst.pl

clean ::
	rm -f genconst\$(OBJ) genconst\$(EXE) np_perl.\$(DLEXT) \$(OBJ_LIB) config.h Makefile

EOF



